# WsectionC.tcl: tcl procedure for creating a two wide flange steel fiber section built up perpendicular
# written: Dr. Erol Kalkan
#
 		#######
		   #
      #	   #		#
      #	   #		#
      ###################
      #	   #		#
      #	   #		#
		   #
 		#######

proc wsectionC {secID matID d tw bf tf d2 tw2 bf2 tf2 nfdw nftw nfbf nftf nfdw2 nftw2 nfbf2 nftf2} {
  # input parameters
  # secID - section ID number
  # matID - material ID number 
  # d  = nominal depth
  # tw = web thickness
  # bf = flange width
  # tf = flange thickness

  # 90deg rotated I-section
  # d2  = nominal depth
  # tw2 = web thickness
  # bf2  = flange width
  # tf2 = flange thickness

  # nfdw = number of fibers along web depth 
  # nftw = number of fibers along web thickness
  # nfbf = number of fibers along flange width
  # nftf = number of fibers along flange thickness

  # 90deg rotated I-section
  # nfdw2 = number of fibers along web depth 
  # nftw2 = number of fibers along web thickness
  # nfbf2 = number of fibers along flange width
  # nftf2 = number of fibers along flange thickness 
  
  set dw [expr $d - 2 * $tf]
  set y1 [expr -$d/2]
  set y2 [expr -$dw/2]
  set y3 [expr  $dw/2]
  set y4 [expr  $d/2]

  set y5 [expr -$tw2/2]
  set y6 [expr  $tw2/2]
  set y7 [expr -$bf2/2]
  set y8 [expr  $bf2/2]
  
  set z1 [expr -$bf/2]
  set z2 [expr -$tw/2]
  set z3 [expr  $tw/2]
  set z4 [expr  $bf/2]
  
  set dw2 [expr $d2 - 2 * $tf2]
  set z5 [expr  -$dw2/2]
  set z6 [expr   $dw2/2]
  set z7 [expr  -$d2/2]
  set z8 [expr   $d2/2]

  #                           
  section fiberSec  $secID  {
     #                     nfIJ  nfJK    yI  zI    yJ  zJ    yK  zK    yL  zL
     patch quadr  $matID  $nfbf $nftf   $y1 $z4   $y1 $z1   $y2 $z1   $y2 $z4
     patch quadr  $matID  $nftw $nfdw   $y2 $z3   $y2 $z2   $y3 $z2   $y3 $z3
     patch quadr  $matID  $nfbf $nftf   $y3 $z4   $y3 $z1   $y4 $z1   $y4 $z4

  # 90deg rotated I-section
     #                     nfIJ  nfJK    yI  zI    yJ  zJ    yK  zK    yL  zL
     patch quadr  $matID  $nfbf2 $nftf2   $y5 $z2   $y5 $z5   $y6 $z5   $y6 $z2
     patch quadr  $matID  $nfbf2 $nftf2   $y7 $z5   $y7 $z7   $y8 $z7   $y8 $z5
     patch quadr  $matID  $nfbf2 $nftf2   $y5 $z6   $y5 $z3   $y6 $z3   $y6 $z6
     patch quadr  $matID  $nfbf2 $nftf2   $y7 $z8   $y7 $z6   $y8 $z6   $y8 $z8
  }
}












