clear; clc; close all;
%--------------------------------------------------------------------------
h = 8767.7; % TOTAL HEIGHT OF BUILDING
%--------------------------------------------------------------------------
nsucc=0;
for NM=1:7;
    GM=[1:21];
    num=GM(NM);
    ch1 = num2str(num);
    
% Check fail or success    
   fid=0;
   filename = strcat('output/M_',ch1,'.log');
   [fid,message] = fopen(filename, 'r');
   if fid == -1
    disp(message);
   end
   line = fgets(fid);
   dp = line(10:19); % Decision parameter
   if(dp == 'Successful');
    fprintf('Ground motion in process = %5.0f  Status = %s\n',num,dp); 
    nsucc = nsucc+1;
    
    for sn = 1:53;
        StoryDriftFname = strcat('output/M_',ch1,'/Story_DriftX_',num2str(sn),'.out');
        FloorDisplFname = strcat('output/M_',ch1,'/NodalDisp_',num2str(sn),'.out');
        plDefColsFname = strcat('output/M_',ch1,'/pl_def_all_cols_',num2str(sn),'.out');
        plDefBeamsFname = strcat('output/M_',ch1,'/pl_def_all_beams_',num2str(sn),'.out');
        
        sDrift = load(StoryDriftFname);
        fDisp = load(FloorDisplFname);
        sDriftMax(sn) = max(max(abs(sDrift)));
        fDispMax(sn) = max(max(abs(fDisp)))/h;
    
        % Columns    
        colAll =load (plDefColsFname);
        for cNum = 1:12;
            colSt = 2+6*(cNum-1);
            colEn = 5+6*(cNum-1);
            colMax(cNum) = max(max(abs(colAll(:,colSt:colEn))));
        end
        plmax(sn,1) = max(colMax);        
      
        % Beams
        if sn == 50; 
            numBeam = 24;
        elseif sn > 50;
            numBeam = 12;
        else
            numBeam = 16;
        end
        beamAll =load (plDefBeamsFname);
        for bNum = 1:numBeam;
            beamSt = 2+6*(bNum-1);
            beamEn = 5+6*(bNum-1);
            beamMax(bNum) = max(max(abs(beamAll(:,beamSt:beamEn))));
        end
         plmax(sn,2) = max(beamMax);

    end
   end

    beam_plastic_rot=plmax(:,2);
    col_plastic_rot=plmax(:,1);
    maxplrotc(1)=0; maxplrotc(2:sn+1)=plmax(1:sn,1); 
    maxplrotb(1)=0; maxplrotb(2:sn+1)=plmax(1:sn,2); 
   
    dmax=[0 sDriftMax]';
    ddmax=[0 fDispMax]';
    cnt = 0;
    c=[1:sn]';
    for i = 1:2:(length(sDriftMax))*2;
        cnt = cnt+1;
        dmax_new (i) = sDriftMax(cnt);
        dmax_new (i+1) = sDriftMax(cnt);
        s2(i) = c(cnt);
        s2(i+1) = c(cnt);
    end
    s2t(1) = 0;
    s2t(2:sn*2) = s2(1:end-1);
    s2 = s2t; sl = [0 c'];      
    
    IDR(:,nsucc)=dmax_new;
    RDR(:,nsucc)=ddmax;
    Col_Rot(:,nsucc)=maxplrotc';
    Beam_Rot(:,nsucc)=maxplrotb';
end
%--------------------------------------------------------------------------
%                       Mean and Dispersion of RESULTS 
%--------------------------------------------------------------------------
mIDR=mean(IDR,2); sIDR=std(IDR,0,2);
mRDR=mean(RDR,2); sRDR=std(RDR,0,2);
mCol_Rot=mean(Col_Rot,2); sCol_Rot=std(Col_Rot,0,2);
mBeam_Rot=mean(Beam_Rot,2); sBeam_Rot=std(Beam_Rot,0,2);
%--------------------------------------------------------------------------
%                       Median and Dispersion of RESULTS 
%--------------------------------------------------------------------------
medIDR = mean(IDR'); medIDR = medIDR';
medRDR = mean(RDR'); medRDR = medRDR';
medCol_Rot = mean(Col_Rot'); medCol_Rot = medCol_Rot';
medBeam_Rot = mean(Beam_Rot'); medBeam_Rot = medBeam_Rot';


% Plotting
figure(1);
subplot(1,2,1); plot(medIDR,s2,'-s'); hold; plot(medIDR+sIDR,s2,'--'); plot(medIDR-sIDR,s2,'--');
ylabel('Story Level'); xlabel('Inter Story Drift')

subplot(1,2,2); plot(medRDR,sl,'r-s'); hold; plot(medRDR+sRDR,sl,'--'); plot(medRDR-sRDR,sl,'--'); 
xlabel('Roof Drift Ratio');

figure(2);
subplot(1,2,1); plot(medCol_Rot,sl,'k-s'); hold; plot(medCol_Rot+sCol_Rot,sl,'--'); plot(medCol_Rot-sCol_Rot,sl,'--'); 
xlabel('Col. Plastic Rotation');

subplot(1,2,2); plot(medBeam_Rot,sl,'c-s'); hold; plot(medBeam_Rot+sBeam_Rot,sl,'--');  plot(medBeam_Rot-sBeam_Rot,sl,'--'); 
xlabel('Beam Plastic Rotation');

save post_process.mat
report7